/***********************************************************
 * $Id: InvalidExpressionSyntaxException.java 20 2007-03-01 10:45:50Z wglas $
 * 
 * Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: Feb 28, 2007
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 * 
 ***********************************************************/

package org.clazzes.util.comparators;

/**
 * This exception is thrown, whever the syntax of a comparator expression is invalid.
 * 
 * @author wglas
 */
public class InvalidExpressionSyntaxException extends Exception {

    private static final long serialVersionUID = 5143298409365161617L;
    
    private String expression;
    
    /**
     * @param expression The expression which caused the exception.
     * @see Exception#Exception()
     */
    public InvalidExpressionSyntaxException(String expression) {
        super();
        this.expression = expression;
    }

    /**
     * @param msg The error message.
     * @param e The cause of the error.
     * @param expression The expression which caused the exception.
     * 
     * @see Exception#Exception(String, Throwable)
     */
    public InvalidExpressionSyntaxException(String expression, String msg, Throwable e) {
        super(msg, e);
        this.expression = expression;
     }

    /**
     * @param expression The expression which caused the exception.
     * @param msg The error message.
     * 
     * @see Exception#Exception(String)
     */
    public InvalidExpressionSyntaxException(String expression, String msg) {
        super(msg);
        this.expression = expression;
    }

    /**
     * @param expression The expression which caused the exception.
     * @param e The cause of the error.
     * 
     * @see Exception#Exception(Throwable)
     */
    public InvalidExpressionSyntaxException(String expression, Throwable e) {
        super(e);
        this.expression = expression;
    }

    /**
     * @return The expression that caused the exception.
     */
    public String getExpression() {
        return this.expression;
    }

    /* (non-Javadoc)
     * @see java.lang.Throwable#getMessage()
     */
    @Override
    public String getMessage() {
        return "[" + this.expression + "]:" + super.getMessage();
    }

    /* (non-Javadoc)
     * @see java.lang.Throwable#getLocalizedMessage()
     */
    @Override
    public String getLocalizedMessage() {
        return "[" + this.expression + "]:" + super.getLocalizedMessage();
    }

}
