/***********************************************************
 * $Id: IPAddressType.java 4 2006-12-26 19:16:57Z wglas $
 * 
 * Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 2006-03-13
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 * 
 ***********************************************************/

package org.clazzes.util.net;


/**
 * Describes the "nature" of an IP address stored in a string or long.
 * It is dedicated to allow a few semantic checks, e.g. 
 * IPv4 netmasks have only 1s and than only 0s. 
 * Someday we might support IPv6 addresses.
 * 
 * @author lech
 */
public enum IPAddressType {
 
  /**
   * 4 byte Dotted IPv4 address, first an last byte must be non-zero. 
   */
  IPv4Address,
  
  /**
   * Like IPv4Address, but may be 0.0.0.0
   */
  IPv4ListenAddress,

  /**
   * 4 byte Dotted IPv4 netmask. constists of n set bits + 32-n unset bits. 
   */
  IPv4Netmask,
  
  /**
   * 4 byte Dotted IPv4 network address. first byte must be non-zero, last byte must be <255 
   */
  IPv4Network
  
  
}
